@@ -2,24 +2,24 @@
 "factor.congruence" <-
 function (x,y=NULL,digits=2) {
 if(is.null(y)&& is.list(x)) {
-n <- length(x)
-for (i in 1:n) {
-xi <- x[[i]]
-if(length(class(xi)) > 1)  { if(class(xi)[2] =='omega')  {xi <- xi$schmid$sl
-   xi<- as.matrix(xi[,1:(ncol(xi)-2)])}}
-if (!is.matrix(xi)) {xi <- xi$loadings}
+	n <- length(x)
+		for (i in 1:n) {
+			xi <- x[[i]]
+			if(length(class(xi)) > 1)  { if(class(xi)[2] =='omega')  {xi <- xi$schmid$sl
+   												xi<- as.matrix(xi[,1:(ncol(xi)-2)])}}
+			if (!is.matrix(xi)) {if(!is.null(xi$loadings)) {xi <- xi$loadings} else {xi <- as.matrix(xi)}}
 if(i==1) {xg <- xi} else {xg <- cbind(xg,xi)} 
 }
 x <- xg
 if(is.null(y)) y <- xg
 }  else {
 if(length(class(x)) > 1)  { if(class(x)[2] =='omega')  {x <- x$schmid$sl
-   x <- as.matrix(x[,1:(ncol(x)-2)])}}
+  		 x <- as.matrix(x[,1:(ncol(x)-2)])}}
 if(length(class(y)) > 1)  { if(class(y)[2] =='omega')  {y <- y$schmid$sl
-   y <- as.matrix(y[,1:(ncol(y)-2)])}}
+  	 y <- as.matrix(y[,1:(ncol(y)-2)])}}
  
- if (!is.matrix(x)) {x <- x$loadings}
-   if (!is.matrix(y))  { y <- y$loadings }
+ if (!is.matrix(x)) {if(!is.null(x$loadings)) {x <- x$loadings} else {x <- as.matrix(x)}   }
+   if (!is.matrix(y)) {if(!is.null(y$loadings))  { y <- y$loadings } else {y <- as.matrix(y)}}
    }
       
   nx<- dim(x)[2]
