@@ -1,6 +1,7 @@
 # slight changes to combine phi and phi1 from W. Revelle
 # Leo Grtler 07-09-06
 # from http://www.personality-project.org/r/useful.r
+#modified  05/18/08 to correct bug in output detected by Dylan Arena
 "phi" <-
  function(t,digits=2)
 {  # expects: t is a 2 x 2 matrix or a vector of length(4)
@@ -13,4 +14,5 @@
    c.sum <- c.sum/total
    v <- prod(r.sum, c.sum)
    phi <- (t[1,1]/total - c.sum[1]*r.sum[1]) /sqrt(v)
-return(round(phi,2))  }
\ No newline at end of file
+   names(phi) <- NULL
+return(round(phi,digits))  }
\ No newline at end of file
